Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3929)

Unified Diff: chrome/common/autofill_messages.h

Issue 10222017: Make password generation switched by a preference in chrome settings rather than a command line fla… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/autofill_messages.h
diff --git a/chrome/common/autofill_messages.h b/chrome/common/autofill_messages.h
index 8c008d0cba4cbe457bbd71c826627031dff0127e..68b554357d98c2b45bfe898d83ef223771190d1d 100644
--- a/chrome/common/autofill_messages.h
+++ b/chrome/common/autofill_messages.h
@@ -118,10 +118,15 @@ IPC_MESSAGE_ROUTED1(AutofillMsg_SetNodeText,
IPC_MESSAGE_ROUTED1(AutofillMsg_GeneratedPasswordAccepted,
string16 /* generated_password */)
-// Tells the renderer if password generation should be enabled.
+// Tells the renderer if password sync is enabled.
+IPC_MESSAGE_ROUTED1(AutofillMsg_PasswordSyncEnabled,
+ bool /* is_enabled */)
+
+// Tells the renderer if password generation preference is enabled.
IPC_MESSAGE_ROUTED1(AutofillMsg_PasswordGenerationEnabled,
bool /* is_enabled */)
+
// Tells the renderer that the password field has accept the suggestion.
IPC_MESSAGE_ROUTED1(AutofillMsg_AcceptPasswordAutofillSuggestion,
string16 /* username value*/)

Powered by Google App Engine
This is Rietveld 408576698